@@ -32,6 +32,9 @@ STATIC_DATA_INPUTS_ROOT = Path('/ihme/covid-19/static-data')
 SNAPSHOT_ROOT = Path('/ihme/covid-19/snapshot-data/')
 MODEL_INPUTS_ROOT = Path('/ihme/covid-19/model-inputs/')
 VISIT_VOLUME_ROOT = Path('/ihme/covid-19/visit-volume/')
+MORTALITY_RATIO_ROOT = Path('/ihme/covid-19/mortality-ratio')
+INFECTION_FATALITY_RATIO_ROOT = Path('/ihme/covid-19/infection-fatality-ratio')
+HOSPITAL_DEATH_RATIO_ROOT = Path('/ihme/covid-19/hospitalization-death-ratio')
 DEATHS_SPLINE_OUTPUT_ROOT = Path('/ihme/covid-19/deaths-outputs/')
 INFECTIONATOR_OUTPUTS = Path('/ihme/covid-19/seir-inputs')
 SHAPEFILE_ROOT = Path('/ihme/covid-19/shapefiles')
